@@ -143,6 +143,9 @@ class SeaTableAPI(object):
     def _third_party_accounts_url(self):
         return self.server_url + '/api/v2.1/dtable/third-party-account/'
 
+    def _dtable_db_query_url(self):
+        return self.server_url + '/api/v1/dtables/' + self.dtable_uuid + '/query/'
+
     def _get_account_detail(self, account_name):
         url = self._third_party_accounts_url()
         params = {
@@ -739,6 +742,25 @@ class SeaTableAPI(object):
         queryset._execute_conditions()
         return queryset
 
+    def query(self, sql, src='all'):
+        """
+        :param sql: str
+        :param src: src
+        :return: list
+        """
+        if not sql:
+            raise ValueError('sql can not be empty.')
+        url = self._dtable_db_query_url()
+        json_data = {
+            'sql': sql,
+            'src': src
+        }
+        response = requests.post(url, json=json_data, headers=self.headers, timeout=self.timeout)
+        data = parse_response(response)
+        if not data.get('success'):
+            raise Exception(data.get('error_message'))
+        return data.get('results')
+
 
 class Account(object):
     def __init__(self, login_name, password, server_url):
